/*
 * @(#)Cross.java   1.0 17/01/2000
 */
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 * Cross.java - Cross Process program.
 *
 * <p>
 * Description:
 * <p>
 * ===============================================================
 * <p>
 * This file contains routines for solving moments of
 * continuous beams by the Cross Process.  For more details of 
 * this process, refer to class notes of course CIV1127-Analise 
 * de Estruturas II, Dept. of Civil Engineering, PUC-Rio.
 *
 * <p>
 * ===============================================================
 *
 * @version    1.0 31/01/2000
 * @author     Luiz Fernando Martha
 * @author     Andre Cahn
 *
 */
public class Cross extends JApplet
{
 public void init()
 {
  JButton launcher = new JButton("Launch Cross Program on a Window");
  launcher.addActionListener( new ActionListener()
  {
   public void actionPerformed( ActionEvent e )
   {
    new CrossFrame();
   }
  } );
  JPanel panel = new JPanel();
  panel.setBorder( BorderFactory.createEtchedBorder() );
  panel.setLayout( new BorderLayout() );
  panel.add( launcher );
  getContentPane().setLayout( new BorderLayout() );
  getContentPane().add( panel );
 }

 public static void main( String[] args )
 {
  new CrossFrame( true );
 }
}

 /*
 ** ---------------------------------------------------------------
 ** Local classes: 
 */
 
/**
 * This class defines the program's frame and screen.
 */
 class CrossFrame extends JFrame
 {
  CrossPanel target;
  CrossDriverIO driverIO;
  CrossAboutBox credits_dlg;
  JMenuBar menu_bar;
  JMenu file_menu;

  CrossFrame()
  {
   this( false );
  }

  CrossFrame( boolean io_setup )
  {
   addWindowListener( new WindowAdapter()
   {
    public void windowClosing( WindowEvent e )
    {
     dispose();
     System.exit(0);
    }
   } );
  setTitle( "Cross Process of Continuous Beam" );
  target = new CrossPanel();
  if( io_setup)
   driverIO = new CrossDriverIO( target );
  credits_dlg = new CrossAboutBox(this);
  buildMenus( io_setup );
  getContentPane().add( target, BorderLayout.CENTER );
  pack();
  setSize( new Dimension(550,550) );
  show();
 }

 /*
 ** ---------------------------------------------------------------
 ** Private and Protected methods: 
 */

 /*===========================  buildMenus  ========================*/
 /**
  * Creates the menu bar.
  */
 private void buildMenus( boolean io_setup )
 {
  menu_bar = new JMenuBar();
  file_menu = new JMenu( "File" );
  if( io_setup )
  {
   addOpenItem();
   addSaveasItem();
   file_menu.addSeparator();
  }
  addExitItem();
  menu_bar.add( file_menu );
  addAboutItem();
  setJMenuBar( menu_bar );
 }

 /*==========================  addOpenItem  ========================*/
 /**
  * Adds an open function to the file menu.
  */
 private void addOpenItem()
 {
  ImageIcon open1ButtonIcon = new ImageIcon( getClass().getResource("images/openfile.gif") );
  JMenuItem open = new JMenuItem( "Open...", open1ButtonIcon );
  open.addActionListener( new ActionListener()
  {
   public void actionPerformed( ActionEvent e )
   {
    driverIO.openInputCrossFile( file_menu );
   }
  } );
  file_menu.add( open );
 }

 /*==========================  addSaveasItem  ========================*/
 /**
  * Adds a save as function to the file menu.
  */
 private void addSaveasItem()
 {
  ImageIcon saveas1ButtonIcon = new ImageIcon( getClass().getResource("images/savefile.gif") );
  JMenuItem saveas = new JMenuItem( "Save As...", saveas1ButtonIcon );
  saveas.addActionListener( new ActionListener()
  {
   public void actionPerformed( ActionEvent e )
   {
    driverIO.openOutputCrossFile( file_menu );
   }
  } );
  file_menu.add( saveas );
 }

 /*==========================  addExitItem  ========================*/
 /**
  * Adds an exit function to the file menu.
  */
 private void addExitItem()
 {
  JMenuItem exit = new JMenuItem( "Exit" );
  exit.addActionListener( new ActionListener()
  {
   public void actionPerformed( ActionEvent e )
   {
    if( exitDialog() == 0 )
    {
     dispose();
     System.exit(0);
    }
   }
  } );
  file_menu.add( exit );
 }

 /*==========================  exitDialog  =========================*/
 /**
  * Prompts the user for exit confirmation.
  */
 private int exitDialog()
 {
   int confirm = JOptionPane.showOptionDialog( getContentPane(),
                 "Really Exit?", "Exit Confirmation",
                 JOptionPane.YES_NO_OPTION, 
                 JOptionPane.QUESTION_MESSAGE,
                 null, null, null);
   return( confirm );
 }

 /*==========================  addAboutItem  ========================*/
 /**
  * Adds an about function to the menu bar.
  */
 private void addAboutItem()
 {
  JMenuItem about = new JMenuItem( "About" );
  about.addActionListener( new ActionListener()
  {
   public void actionPerformed( ActionEvent e )
   {
    Dimension d1 = credits_dlg.getSize();
    Dimension d2 = CrossFrame.this.getSize();
    int x = Math.max((d2.width-d1.width)/2, 0);
    int y = Math.max((d2.height-d1.height)/2, 0);
    credits_dlg.setBounds(x+CrossFrame.this.getX(), y+CrossFrame.this.getY(),
    d1.width, d1.height);
    credits_dlg.show();
   }
  } );
  menu_bar.add( about );
 }
}