/*
 * @(#)CrossControls.java   1.0 31/01/2000
 */

import java.awt.*;
import java.awt.event.*;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JToolBar;

/**
 * CrossControl.java - Control of Cross Process of continous beams.
 *
 * <p>
 * Description:
 * <p>
 * ===============================================================
 * <p>
 * This file contains an implementation of the Cross Process
 * for continuous beams.  For more details of this process,
 * refer to class notes of course CIV1127-Analise de Estruturas
 * II, Dept. of Civil Engineering, PUC-Rio.
 *
 * <p>
 * ===============================================================
 *
 * @version    1.0 31/01/1999
 * @author     Luiz Fernando Martha
 * @author     Andre Cahn
 *
 */
class CrossControls extends JToolBar
                    implements ActionListener, ItemListener
{
 CrossPanel target;

 /** Button to set the initial support condition.*/
 JButton supinit;

 /** Button to add an internal support on the structure.*/
 JButton support;

 /** Button to delete an support on the structure.*/
 JButton delete;

 /** Button to set the end support conditional.*/
 JButton supend;

 /** Button to restart the Cross solution.*/
 JButton restart;

 /** Button make an interaction of Cross process.*/
 JButton autostep;

 /** Button to solve all the process.*/
 JButton solve;

 /** Choice list for specifying moment precision.*/
 JComboBox precision;

 /** Icon of the released initial support button.*/
 ImageIcon relinit1ButtonIcon;

 /** Icon of the fixed initial support button.*/
 ImageIcon fixinit1ButtonIcon;

 /** Icon of the add internal support button.*/
 ImageIcon support1ButtonIcon;

 /** Icon of the add internal support button(pressed).*/
 ImageIcon support2ButtonIcon;

 /** Icon of the delete button.*/
 ImageIcon delete1ButtonIcon;

 /** Icon of the delete button (pressed).*/
 ImageIcon delete2ButtonIcon;

 /** Icon of the released final support button.*/
 ImageIcon relend1ButtonIcon;

 /** Icon of the fixed final support button.*/
 ImageIcon fixend1ButtonIcon;

 /** Icon of the restart solution button.*/
 ImageIcon restart1ButtonIcon;

 /** Icon of the one step interaction button.*/
 ImageIcon step1ButtonIcon;

 /** Icon of the solve all process button.*/
 ImageIcon solve1ButtonIcon;

/*=========================  Constructor  ==========================*/

 CrossControls( CrossPanel target )
 {
  this.target = target;
  setFloatable( false );

  relinit1ButtonIcon = new ImageIcon( getClass().getResource("images/relinit1.gif") );
  fixinit1ButtonIcon = new ImageIcon( getClass().getResource("images/fixinit1.gif") );
  support1ButtonIcon = new ImageIcon( getClass().getResource("images/support1.gif") );
  support2ButtonIcon = new ImageIcon( getClass().getResource("images/support2.gif") );
  delete1ButtonIcon  = new ImageIcon( getClass().getResource("images/delete1.gif") );
  delete2ButtonIcon  = new ImageIcon( getClass().getResource("images/delete2.gif") );
  relend1ButtonIcon  = new ImageIcon( getClass().getResource("images/relend1.gif") );
  fixend1ButtonIcon  = new ImageIcon( getClass().getResource("images/fixend1.gif") );
  restart1ButtonIcon = new ImageIcon( getClass().getResource("images/restart1.gif") );
  step1ButtonIcon    = new ImageIcon( getClass().getResource("images/step1.gif") );
  solve1ButtonIcon   = new ImageIcon( getClass().getResource("images/solve1.gif") );

  supinit = new JButton( "", fixinit1ButtonIcon );
  supinit.setBorder( BorderFactory.createEmptyBorder() );
  supinit.setToolTipText( "Fix initial rotation." );
  supinit.setActionCommand( "sup init" );
  supinit.addActionListener( this );

  support = new JButton( "", support1ButtonIcon );
  support.setBorder( BorderFactory.createEmptyBorder() );
  support.setToolTipText( "Add internal support." );
  support.setActionCommand( "support" );
  support.addActionListener( this );

  delete = new JButton( "", delete1ButtonIcon );
  delete.setBorder( BorderFactory.createEmptyBorder() );
  delete.setToolTipText( "Delete internal support." );
  delete.setActionCommand( "delete" );
  delete.addActionListener( this );

  supend = new JButton( "", relend1ButtonIcon );
  supend.setBorder( BorderFactory.createEmptyBorder() );
  supend.setToolTipText( "Release end rotation." );
  supend.setActionCommand( "sup end" );
  supend.addActionListener( this );

  restart = new JButton( "", restart1ButtonIcon );
  restart.setBorder( BorderFactory.createEmptyBorder() );
  restart.setToolTipText( "Restart Cross solution." );
  restart.setActionCommand( "restart" );
  restart.addActionListener( this );

  autostep = new JButton( "", step1ButtonIcon );
  autostep.setBorder( BorderFactory.createEmptyBorder() );
  autostep.setToolTipText( "Process one Cross iteration." );
  autostep.setActionCommand( "autostep" );
  autostep.addActionListener( this );

  solve = new JButton( "", solve1ButtonIcon );
  solve.setBorder( BorderFactory.createEmptyBorder() );
  solve.setToolTipText( "Go through Cross solution." );
  solve.setActionCommand( "solve" );
  solve.addActionListener( this );

  precision = new JComboBox();
  precision.setMaximumSize( new Dimension( 90, 30 ) );
  precision.setToolTipText( "Moment precision" );
  precision.addItem( "1 kNm" );
  precision.addItem( "0.1 kNm" );
  precision.addItem( "0.01 kNm" );
  precision.setSelectedIndex( 1 );
  precision.addItemListener( this );

  add( supinit );
  add( support );
  add( delete );
  add( supend );
  addSeparator();
  add( restart );
  add( autostep );
  add( solve );
  addSeparator();
  add( precision );
 }

/*========================  actionPerformed  ========================*/
/**
  * This method notices a action performed in one of the buttons.
  */
 public void actionPerformed( ActionEvent e )
 {
  if( e.getActionCommand().equals("sup init") )
  {
   target.model_canvas.support_insertion = false;
   support.setIcon( support1ButtonIcon );
   target.model_canvas.support_deletion = false;
   delete.setIcon( delete1ButtonIcon );
   if( target.driver.getInitRotationCode() == 0 )
   {
    target.driver.fixInitRotation();
    supinit.setIcon( relinit1ButtonIcon );
    supinit.setToolTipText( "Release initial rotation." );
   }
   else
   {
    target.driver.releaseInitRotation();
    supinit.setIcon( fixinit1ButtonIcon );
    supinit.setToolTipText( "Fix initial rotation." );
   }
   target.model_canvas.repaint();
   target.deform_canvas.repaint();
   target.moment_canvas.repaint();
   target.solution_canvas.reset();
   if( target.driver.moreCrossSteps() )
    target.setMsg( "Moments are not balanced yet." );
   else
    target.setMsg( "Cross Solution performed." );
  }
  else if( e.getActionCommand().equals("support") )
  {
   target.setMsg( "Add internal support." );
   target.model_canvas.support_insertion = true;
   support.setIcon( support2ButtonIcon );
   target.model_canvas.support_deletion = false;
   delete.setIcon( delete1ButtonIcon );
  }
  else if( e.getActionCommand().equals("delete") )
  {
   target.setMsg( "Delete internal support." );
   target.model_canvas.support_insertion = false;
   support.setIcon( support1ButtonIcon );
   target.model_canvas.support_deletion = true;
   delete.setIcon( delete2ButtonIcon );
  }
  else if( e.getActionCommand().equals("sup end") )
  {
   target.model_canvas.support_insertion = false;
   support.setIcon( support1ButtonIcon );
   target.model_canvas.support_deletion = false;
   delete.setIcon( delete1ButtonIcon );
   if( target.driver.getEndRotationCode() == 0 )
   {
    target.driver.fixEndRotation();
    supend.setIcon( relend1ButtonIcon );
    supend.setToolTipText( "Release end rotation." );
   }
   else
   {
    target.driver.releaseEndRotation();
    supend.setIcon( fixend1ButtonIcon );
    supend.setToolTipText( "Fix end rotation." );
   }
   target.model_canvas.repaint();
   target.deform_canvas.repaint();
   target.moment_canvas.repaint();
   target.solution_canvas.reset();
   if( target.driver.moreCrossSteps() )
    target.setMsg( "Moments are not balanced yet." );
   else
    target.setMsg( "Cross Solution performed." );
  }
  else if( e.getActionCommand().equals("restart") )
  {
   target.driver.resetCrossSolver();
   target.model_canvas.support_insertion = false;
   support.setIcon( support1ButtonIcon );
   target.model_canvas.support_deletion = false;
   delete.setIcon( delete1ButtonIcon );
   target.model_canvas.repaint();
   target.deform_canvas.repaint();
   target.moment_canvas.repaint();
   target.solution_canvas.reset();
   if( target.driver.moreCrossSteps() )
    target.setMsg( "Moments are not balanced yet." );
   else
    target.setMsg( "Cross Solution performed." );
  }
  else if( e.getActionCommand().equals("autostep") )
  {
   if( target.driver.autoStepCross() )
    target.setMsg( "Moments are not balanced yet." );
   else
    target.setMsg( "Cross Solution performed." );
   target.model_canvas.support_insertion = false;
   support.setIcon( support1ButtonIcon );
   target.model_canvas.support_deletion = false;
   delete.setIcon( delete1ButtonIcon );
   target.model_canvas.repaint();
   target.deform_canvas.repaint();
   target.moment_canvas.repaint();
   target.solution_canvas.update();
  }
  else if( e.getActionCommand().equals("solve") )
  {
   target.driver.goThruCross();
   target.setMsg( "Cross Solution performed." );
   target.model_canvas.support_insertion = false;
   support.setIcon( support1ButtonIcon );
   target.model_canvas.support_deletion = false;
   delete.setIcon( delete1ButtonIcon );
   target.model_canvas.repaint();
   target.deform_canvas.repaint();
   target.moment_canvas.repaint();
   target.solution_canvas.update();
  }
 }

/*========================  itemStateChanged  =======================*/
/**
  * This method notices a item state change of the moment precision list.
  */
 public void itemStateChanged( ItemEvent e )
 {
  if (e.getStateChange() == ItemEvent.SELECTED )
  {
   String choice = (String)e.getItem();
   if( choice.equals("1 kNm") )
   {
    target.driver.setMomentPrecision( 0 );
   }
   else if( choice.equals("0.1 kNm") )
   {
    target.driver.setMomentPrecision( 1 );
   }
   else if( choice.equals("0.01 kNm") )
   {
    target.driver.setMomentPrecision( 2 );
   }
   target.moment_canvas.repaint();
   target.solution_canvas.repaint();
   if( target.driver.moreCrossSteps() )
    target.setMsg( "Moments are not balanced yet." );
   else
    target.setMsg( "Cross Solution performed." );
  }
 }

/*========================  resetButtons  ==========================*/
/**
  * Reset all buttons.
  */
 void resetButtons()
 {
  target.model_canvas.support_insertion = false;
  support.setIcon( support1ButtonIcon );
  target.model_canvas.support_deletion = false;
  delete.setIcon( delete1ButtonIcon );

  if( target.driver.getInitRotationCode() == 0 )
  {
   supinit.setIcon( fixinit1ButtonIcon );
   supinit.setToolTipText( "Fix initial rotation." );
  }
  else
  {
   supinit.setIcon( relinit1ButtonIcon );
   supinit.setToolTipText( "Release initial rotation." );
  }
  if( target.driver.getEndRotationCode() == 0 )
  {
   supend.setIcon( fixend1ButtonIcon );
   supend.setToolTipText( "Fix end rotation." );
  }
  else
  {
   supend.setIcon( relend1ButtonIcon );
   supend.setToolTipText( "Release end rotation." );
  }

  switch( target.driver.getMomentPrecision() )
  {
   case 0:
    precision.setSelectedIndex( 0 );
    break;
   default:
   case 1:
    precision.setSelectedIndex( 1 );
    break;
   case 2:
    precision.setSelectedIndex( 2 );
    break;
  }
 }
}
