/*
 * @(#)CrossEndFreeRotSup.java   1.0 31/01/2000
 */
import java.awt.*;
import java.awt.geom.*;

/**
 * This class defines the free rotation end support figure of a  
 * continuous beam for the Cross Process.
 */
 class CrossEndFreeRotSup
 {
  Point2D.Double toppnt;/** top point of the triangular support image.*/
  Point2D.Double leftpnt;/** left point of the triangular support image.*/
  Point2D.Double rightpnt;/** right point of the triangular support image.*/
  Point2D.Double grnd1up;  /** make the fixed support effect.*/
  Point2D.Double grnd2up;  /** make the fixed support effect.*/
  Point2D.Double grnd3up;  /** make the fixed support effect.*/
  Point2D.Double grnd4up;  /** make the fixed support effect.*/
  Point2D.Double grnd5up;  /** make the fixed support effect.*/
 
  Point2D.Double grnd1low; /** make the fixed support effect.*/
  Point2D.Double grnd2low; /** make the fixed support effect.*/
  Point2D.Double grnd3low; /** make the fixed support effect.*/
  Point2D.Double grnd4low; /** make the fixed support effect.*/
  Point2D.Double grnd5low; /** make the fixed support effect.*/

  Line2D.Double leftline;  /** left line of the support*/
  Line2D.Double rightline; /** right line of the support*/
  Line2D.Double	bottomline;/** bottom line of the support*/
  Line2D.Double grdline1;  /** ground effect line of the support*/
  Line2D.Double grdline2;  /** ground effect line of the support*/
  Line2D.Double grdline3;  /** ground effect line of the support*/
  Line2D.Double grdline4;  /** ground effect line of the support*/
  Line2D.Double	grdline5;  /** ground effect line of the support*/			

/*==========================  Constructor  =========================*/

  CrossEndFreeRotSup()
  {
   toppnt     = new Point2D.Double(  0.0 ,  0.0 );     
   leftpnt    = new Point2D.Double( -0.5 , -0.866025 );
   rightpnt   = new Point2D.Double(  0.5 , -0.866025 );
   
   grnd1up    = new Point2D.Double( -0.50, -0.866025 ); 
   grnd2up    = new Point2D.Double( -0.25, -0.866025 );
   grnd3up    = new Point2D.Double(  0.00, -0.866025 );
   grnd4up    = new Point2D.Double(  0.25, -0.866025 );
   grnd5up    = new Point2D.Double(  0.50, -0.866025 );
   
   grnd1low   = new Point2D.Double( -0.30, -1.14 );
   grnd2low   = new Point2D.Double( -0.05, -1.14 );
   grnd3low   = new Point2D.Double(  0.20, -1.14 );
   grnd4low   = new Point2D.Double(  0.45, -1.14 );
   grnd5low   = new Point2D.Double(  0.70, -1.14 );

   leftline   = new Line2D.Double( leftpnt, toppnt );
   rightline  = new Line2D.Double( rightpnt, toppnt );
   bottomline = new Line2D.Double( leftpnt, rightpnt );
   grdline1   = new Line2D.Double( grnd1up, grnd1low );
   grdline2   = new Line2D.Double( grnd2up, grnd2low );
   grdline3   = new Line2D.Double( grnd3up, grnd3low );
   grdline4   = new Line2D.Double( grnd4up, grnd4low );
   grdline5   = new Line2D.Double( rightpnt, grnd5low );
  }
 
/*=============================  draw  =============================*/
 /**
  * Draw the support figure.
  */
  void draw( Graphics2D g, double x, double y, double size )
  {
   double sizex = Math.abs( size );
   double sizey = size;

   /** draw the support triangle line. */
   leftline.setLine(x + leftpnt.getX()*sizex, y + leftpnt.getY()*sizey, 
                    x + toppnt.getX()*sizex, y + toppnt.getY()*sizey );
                   
   /** draw the support triangle line. */ 
   rightline.setLine(x + rightpnt.getX()*sizex, y + rightpnt.getY()*sizey,
                     x + toppnt.getX()*sizex, y + toppnt.getY()*sizey );
   
   /** draw the support triangle line.*/
   bottomline.setLine(x + leftpnt.getX()*sizex, y + leftpnt.getY()*sizey,
                      x + rightpnt.getX()*sizex, y + rightpnt.getY()*sizey );
   
   /** draw the fixed support effect.*/
   grdline1.setLine(x + grnd1up.getX()*sizex, y + grnd1up.getY()*sizey,
                    x + grnd1low.getX()* sizex, y + grnd1low.getY()*sizey );	 
   
   /** draw the fixed support effect.*/
   grdline2.setLine(x + grnd2up.getX()*sizex, y + grnd2up.getY()*sizey,
                    x + grnd2low.getX()* sizex, y + grnd2low.getY()*sizey );	 
   
   /** draw the fixed support effect.*/
   grdline3.setLine(x + grnd3up.getX()*sizex, y + grnd3up.getY()*sizey,
                    x + grnd3low.getX()* sizex, y + grnd3low.getY()*sizey );	 
   
   /** draw the fixed support effect.*/
   grdline4.setLine(x + grnd4up.getX()*sizex, y + grnd4up.getY()*sizey,
                    x + grnd4low.getX()* sizex, y + grnd4low.getY()*sizey );	 
   
   /** draw the fixed support effect.*/
   grdline5.setLine(x + grnd5up.getX()*sizex, y + grnd5up.getY()*sizey,
                    x + grnd5low.getX()* sizex, y + grnd5low.getY()*sizey );	 

   g.draw( leftline ); 	/** draw the left line of the support.*/
   g.draw( rightline );	/** draw the right line of the support.*/
   g.draw( bottomline );/** draw the bottom line of the support.*/
   g.draw( grdline1 );	/** draw the ground line support effect.*/
   g.draw( grdline2 );	/** draw the ground line support effect.*/
   g.draw( grdline3 );	/** draw the ground line support effect.*/
   g.draw( grdline4 );	/** draw the ground line support effect.*/
   g.draw( grdline5 );	/** draw the ground line support effect.*/
  }
 }