/*
 * @(#)CrossIntSup.java   1.0 31/01/2000
 */
import java.awt.*;
import java.awt.geom.*;

/**
 * This class defines the internal support figure of a continuous 
 * beam for the Cross Process.
 */
 class CrossIntSup
 {
  Point2D.Double toppt;/** top point of the triangular support image.*/
  Point2D.Double leftpt;/** left point of the triangular support image.*/
  Point2D.Double rightpt;/** right point of the triangular support image.*/
  Point2D.Double baseleftpt;/** left point to draw the base line */
  Point2D.Double baserightpt;/** right point to draw the base line */
  GeneralPath triangle; /** triangle area to be filled with fill color*/
  Line2D.Double baseln; /** base line of the triangular support image*/


/*==========================  Constructor  =========================*/
	
  CrossIntSup()
  {
   toppt       = new Point2D.Double(  0.0,  0.0 );
   leftpt      = new Point2D.Double( -0.5, -0.866025 );
   rightpt     = new Point2D.Double(  0.5, -0.866025 );
   baseleftpt  = new Point2D.Double( -0.5, -1.016025 );
   baserightpt = new Point2D.Double(  0.5, -1.016025 );
   triangle    = new GeneralPath();
   baseln      = new Line2D.Double( baseleftpt, baserightpt );
  }

/*=============================  draw  =============================*/
/**
 * Draw the hollow support figure.
 */
  void draw( Graphics2D g, double x, double y, double size )
  {
   double sizex = Math.abs( size );
   double sizey = size;
   triangle.reset();
   triangle.moveTo( (float)(x + leftpt.getX()*sizex),  (float)(y + leftpt.getY()*sizey) );
   triangle.lineTo( (float)(x + toppt.getX()*sizex),   (float)(y + toppt.getY()*sizey) );
   triangle.lineTo( (float)(x + rightpt.getX()*sizex), (float)(y + rightpt.getY()*sizey) );
   triangle.lineTo( (float)(x + leftpt.getX()*sizex),  (float)(y + leftpt.getY()*sizey) );
   baseln.setLine( x + baseleftpt.getX()*sizex, y + baseleftpt.getY()*sizey, 
                   x + baserightpt.getX()*sizex, y + baserightpt.getY()*sizey );
   g.draw( triangle );
   g.draw( baseln );
  }

/**
 * Draw the hollow support figure.
 */
  void draw( Graphics2D g, boolean filled, Color foreground, Color fillcolor,
             double x, double y, double size )
  {
   triangle.reset();
   triangle.moveTo( (float)(x + leftpt.getX()*size),  (float)(y + leftpt.getY()*size) );
   triangle.lineTo( (float)(x + toppt.getX()*size),   (float)(y + toppt.getY()*size) );
   triangle.lineTo( (float)(x + rightpt.getX()*size), (float)(y + rightpt.getY()*size) );
   triangle.lineTo( (float)(x + leftpt.getX()*size),  (float)(y + leftpt.getY()*size) );
   baseln.setLine( x + baseleftpt.getX()*size, y + baseleftpt.getY()*size, 
                   x + baserightpt.getX()*size, y + baserightpt.getY()*size );
   if( filled )
   {
    g.setColor( fillcolor );
    g.fill( triangle );
   }
   g.setColor( foreground );
   g.draw( triangle );
   g.draw( baseln );
  }
 }
