/*
 * @(#)CrossPanel.java   1.0 01/02/2000
 */
import java.awt.BorderLayout;
import java.awt.GridLayout;
import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.BorderFactory;

/**
 * CrossPanel.java - Defines the interface panel of the Cross 
 * Process program.
 *
 * <p>
 * Description:
 * <p>
 * ===============================================================
 * <p>
 * This file contains an implementation of the Cross Process
 * for continuous beams.  For more details of this process,
 * refer to class notes of course CIV1127-Analise de Estruturas
 * II, Dept. of Civil Engineering, PUC-Rio.
 *
 * <p>
 * ===============================================================
 *
 * @version    1.0 01/02/2000
 * @author     Luiz Fernando Martha
 * @author     Andre Cahn
 *
 */
class CrossPanel extends JPanel
{
 CrossDriver driver;
 CrossControls controls;
 JLabel msg;
 CrossModelCanvas model_canvas;
 CrossDeformCanvas deform_canvas;
 CrossMomentCanvas moment_canvas;
 CrossSolutionCanvas solution_canvas;

 CrossPanel()
 {
  driver = new CrossDriver( this );
  controls = new CrossControls( this );

  msg = new JLabel( "Moments are not balanced yet." );
  msg.setBorder( BorderFactory.createEtchedBorder() );

  JPanel control_panel = new JPanel();
  control_panel.setLayout( new GridLayout( 2, 1 ) );
  control_panel.add( controls );
  control_panel.add( msg );

  model_canvas = new CrossModelCanvas( this );
  deform_canvas = new CrossDeformCanvas( this );
  moment_canvas = new CrossMomentCanvas( this );
  solution_canvas = new CrossSolutionCanvas( this );

  JPanel model_panel = new JPanel();
  model_panel.setLayout( new BorderLayout() );
  model_panel.add( model_canvas );
  model_panel.setBorder( BorderFactory.createTitledBorder( "Continuous Beam" ) );

  JPanel deform_panel = new JPanel();
  deform_panel.setLayout( new BorderLayout() );
  deform_panel.add( deform_canvas );
  deform_panel.setBorder( BorderFactory.createTitledBorder( "Deformed Configuration (amplified)" ) );

  JPanel moment_panel = new JPanel();
  moment_panel.setLayout( new BorderLayout() );
  moment_panel.add( moment_canvas );
  moment_panel.setBorder( BorderFactory.createTitledBorder( "Bending Moment Diagram [kNm]" ) );

  JPanel solution_panel = new JPanel();
  solution_panel.setLayout( new BorderLayout() );
  solution_panel.add( solution_canvas );
  solution_panel.setBorder( BorderFactory.createTitledBorder( "Iterative Cross Solution" ) );

  JPanel canvases = new JPanel();
  canvases.setLayout( new GridLayout( 4, 1 ) );
  canvases.add( model_panel );
  canvases.add( deform_panel );
  canvases.add( moment_panel );
  canvases.add( solution_panel );

  setLayout( new BorderLayout() );
  add( "North", control_panel );
  add( "Center", canvases );
 }

 void setMsg( String txt )
 {
  msg.setText( txt );
 }
}